@@ -58,7 +58,7 @@ pkg_deps <- function(x = "tidymodels", recursive = FALSE) {
   if ("tidymodels" %in% x && is.null(deps$tidymodels)) {
     deps$tidymodels <-
       c(
-        "broom", "cli", "crayon", "dials", "dplyr", "ggplot2", "infer",
+        "broom", "cli", "dials", "dplyr", "ggplot2", "infer",
         "magrittr", "modeldata", "parsnip", "pillar", "purrr", "recipes",
         "rlang", "rsample", "rstudioapi", "tibble", "tidyr", "tune",
         "workflows", "yardstick"
